@@ -13,6 +13,8 @@ SECRET_KEY = env('SECRET_KEY')
 # SECURITY WARNING: don't run with debug turned on in production!
 DEBUG = env.bool('DEBUG', True)
 
+API_URL = 'api'  # or api/v1, or api/v2, etc
+
 ALLOWED_HOSTS = ['*']
 
 SITE_ID = 1
@@ -30,6 +32,7 @@ INSTALLED_APPS = [
     'django.contrib.sessions',
     'django.contrib.messages',
     'django.contrib.staticfiles',
+    'django.contrib.sitemaps',
     'ckeditor',
     'ckeditor_uploader',
     'rest_framework',
@@ -41,12 +44,13 @@ INSTALLED_APPS = [
     'oauth2_provider',
     'social_django',
     # garpixcms
+    'garpix_utils',
     'garpix_qa',
     'garpix_page',
     'garpix_menu',
     'garpix_notify',
     'garpix_package',
-    'drf_yasg',
+    'drf_spectacular',
     'garpixcms',
     # website
     'app',
@@ -208,6 +212,14 @@ FCM_DJANGO_SETTINGS = {
     "FCM_SERVER_KEY": env('FCM_SERVER_KEY', "1234567890")
 }
 
+# SPECTACULAR
+
+SPECTACULAR_SETTINGS = {
+    'TITLE': 'Application',
+    'DESCRIPTION': '',
+    'VERSION': '1.0.0',
+}
+
 # Celery
 
 REDIS_HOST = os.getenv('REDIS_HOST', 'localhost')
@@ -249,7 +261,8 @@ REST_FRAMEWORK = {
         'garpix_auth.rest.authentication.MainAuthentication',
         'oauth2_provider.contrib.rest_framework.OAuth2Authentication',
         'rest_framework_social_oauth2.authentication.SocialAuthentication',
-    )
+    ),
+    'DEFAULT_SCHEMA_CLASS': 'drf_spectacular.openapi.AutoSchema',
 }
 
 AUTHENTICATION_BACKENDS = [
